# elastic-apm-zf1

This is the base project for Zend Framework 1 integration with Elastic APM.

It will give an easy way for bootstrapping and configuring the Elastic APM agent.

## example bootstrap via Zend_Bootstrap

``application.ini`` configuration

```ini
;#################### Elastic APM ####################
elasticapm.active = true
elasticapm.appname = "test"
elasticapm.serverurl = "http://127.0.0.1:8200"
elasticapm.secrettoken = ""
```

``Zend_Bootstrap`` class function

```php
protected function _initElasticApm()
{
    $release = 'dummy';
    $releaseFilePath = APPLICATION_PATH.'/../revision.txt';

    if (file_exists($releaseFilePath))
    {
        $release = file_get_contents($releaseFilePath);
    }
    $config = $this->getOption('elasticapm');

    /*
     * appName       : Name of this application, Required
     * appVersion    : Application version, Default: ''
     * serverUrl     : APM Server Endpoint, Default: 'http://127.0.0.1:8200'
     * secretToken   : Secret token for APM Server, Default: null
     * hostname      : Hostname to transmit to the APM Server, Default: gethostname()
     * active        : Activate the APM Agent, Default: true
     * timeout       : Guzzle Client timeout, Default: 5
     * env           : $_SERVER vars to send to the APM Server, empty set sends all. Keys are case sensitive, Default: ['SERVER_SOFTWARE']
     * cookies       : Cookies to send to the APM Server, empty set sends all. Keys are case sensitive, Default: []
     * httpClient    : Extended GuzzleHttp\Client Default: []
     * environment   : application environment, default: 'development'
     * backtraceLimit: Depth of a transaction backtrace, Default: unlimited
     */

    $active = PHP_SAPI !== 'cli' && $config['active'];

    if ($active)
    {
        $config = [
            'appName'     => $config['appname'],
            'appVersion'  => $release,
            'serverUrl'   => $config['serverurl'],
            'active'      => $active,
            'secretToken' => $config['secrettoken'],
            'environment' => APPLICATION_ENV,
            //'hostname'    => 'test01',
            //'env'         => ['DOCUMENT_ROOT', 'REMOTE_ADDR', 'REMOTE_USER', 'APPLICATION_ENV'],
            //'cookies'     => ['my-cookie'],
            /*'httpClient'  => [
                'verify' => false,
                'proxy'  => 'tcp://localhost:8125'
            ],*/
        ];

        \DeubertIt\ElasticApm\Base::bootstrap($config);

        try {
            $elasticApmAgent = \DeubertIt\ElasticApm\Base::getRegistryInstance();

            $transaction = $elasticApmAgent->startTransaction('Bootstrap-Transaction');

            \Zend_Registry::set('elastic-apm-agent_maintransaction', $transaction);
        }
        catch (\Exception $e)
        {
            \Zend_Registry::get('logger')->err('error when setting up elastic apm agent: '.$e->getMessage());
        }
    }
}
```